<?php

namespace Drupal\Tests\ssch\Kernel;

use Drupal\Core\Field\FieldItemInterface;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\entity_test\Entity\EntityTest;
use Drupal\field\Entity\FieldConfig;
use Drupal\field\Entity\FieldStorageConfig;
use Drupal\Tests\field\Kernel\FieldKernelTestBase;

/**
 * Tests the entity API for the ssch field type.
 *
 * @group ssch
 */
class ServerSidedCodeHighlightingItemTest extends FieldKernelTestBase {

  /**
   * Modules to enable.
   *
   * @var array
   */
  public static $modules = ['ssch'];

  /**
   * {@inheritdoc}
   */
  protected function setUp() {
    parent::setUp();

    // Create a ssch field storage and field for validation.
    FieldStorageConfig::create([
      'field_name' => 'field_test',
      'entity_type' => 'entity_test',
      'type' => 'ssch',
    ])->save();
    FieldConfig::create([
      'entity_type' => 'entity_test',
      'field_name' => 'field_test',
      'bundle' => 'entity_test',
    ])->save();
  }

  /**
   * Tests using entity fields of the ssch field type.
   */
  public function testServerSidedCodeHighlightingItem() {
    $language = 'php';
    $code_snippet = '<?php phpinfo(); ?>';

    // Verify entity creation.
    $entity = EntityTest::create();
    $entity->name->value = $this->randomMachineName();
    $entity->field_test->language = $language;
    $entity->field_test->value = $code_snippet;
    $entity->save();

    // Verify entity has been created properly.
    $id = $entity->id();
    $entity = EntityTest::load($id);
    $this->assertInstanceOf(FieldItemListInterface::class, $entity->field_test);
    $this->assertInstanceOf(FieldItemInterface::class, $entity->field_test[0]);
    $this->assertEqual($entity->field_test->language, $language);
    $this->assertEqual($entity->field_test[0]->language, $language);
    $this->assertEqual($entity->field_test->value, $code_snippet);
    $this->assertEqual($entity->field_test[0]->value, $code_snippet);

    // Verify changing the field value.
    $new_language = 'json';
    $new_code_snippet = '{"test":"test"}';
    $entity->field_test->language = $new_language;
    $entity->field_test->value = $new_code_snippet;
    $this->assertEqual($entity->field_test->language, $new_language);
    $this->assertEqual($entity->field_test->value, $new_code_snippet);

    // Read changed entity and assert changed values.
    $entity->save();
    $entity = EntityTest::load($id);
    $this->assertEqual($entity->field_test->language, $new_language);
    $this->assertEqual($entity->field_test->value, $new_code_snippet);
  }

}
